fn atlas_layout(edges: &[AtlasPreviewEdge]) -> AtlasLayoutExpand description
Settle one connected graph with the reusable force engine and center its strongest hub.
fn atlas_layout(edges: &[AtlasPreviewEdge]) -> AtlasLayoutSettle one connected graph with the reusable force engine and center its strongest hub.