pub(crate) fn capture_token_dashboard_viewport() -> TokenDashboardViewportExpand description
Capture one validated viewport for token loading, rendering, and serialization.
pub(crate) fn capture_token_dashboard_viewport() -> TokenDashboardViewportCapture one validated viewport for token loading, rendering, and serialization.