fn file_handling_token_mix(overview: &TokenOverview) -> TokenMixExpand description
Return the token operands that back the composition panel.
fn file_handling_token_mix(overview: &TokenOverview) -> TokenMixReturn the token operands that back the composition panel.