fn render_atlas_map(
frame: &mut Frame<'_>,
area: Rect,
atlas: &TokenAtlasPreview,
)Expand description
Draw the bounded live repository constellation in the wide dashboard column.
fn render_atlas_map(
frame: &mut Frame<'_>,
area: Rect,
atlas: &TokenAtlasPreview,
)Draw the bounded live repository constellation in the wide dashboard column.