pub(crate) fn render_token_dashboard_plain_with_theme(
overview: &TokenOverview,
session: Option<&str>,
theme: TokenDashboardTheme,
) -> StringExpand description
Render the token overview as a plain terminal chart for agent payloads.
pub(crate) fn render_token_dashboard_plain_with_theme(
overview: &TokenOverview,
session: Option<&str>,
theme: TokenDashboardTheme,
) -> StringRender the token overview as a plain terminal chart for agent payloads.