pub(crate) fn render_token_trend_dashboard_with_theme(
report: &TokenTrendReport,
theme: TokenDashboardTheme,
) -> StringExpand description
Render token trends as a human terminal dashboard with the selected theme.
pub(crate) fn render_token_trend_dashboard_with_theme(
report: &TokenTrendReport,
theme: TokenDashboardTheme,
) -> StringRender token trends as a human terminal dashboard with the selected theme.