pub(crate) fn token_dashboard_wants_atlas(
viewport: TokenDashboardViewport,
) -> boolExpand description
Return whether a captured viewport can show the optional atlas.
pub(crate) fn token_dashboard_wants_atlas(
viewport: TokenDashboardViewport,
) -> boolReturn whether a captured viewport can show the optional atlas.